api.customers.v1.test_helpers.customer package — Argus-Toolbelt 1.0 documentation

# api.customers.v1.test_helpers.customer package

## Submodules

## api.customers.v1.test_helpers.customer.add_customer module

`api.customers.v1.test_helpers.customer.add_customer.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer, respond with HTTP 403

`api.customers.v1.test_helpers.customer.add_customer.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer, respond with HTTP 404

`api.customers.v1.test_helpers.customer.add_customer.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer, respond with HTTP 200

`api.customers.v1.test_helpers.customer.add_customer.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer, respond with HTTP 401

## api.customers.v1.test_helpers.customer.add_customer_service module

`api.customers.v1.test_helpers.customer.add_customer_service.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/service, respond with HTTP 403

`api.customers.v1.test_helpers.customer.add_customer_service.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/service, respond with HTTP 404

`api.customers.v1.test_helpers.customer.add_customer_service.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/service, respond with HTTP 200

`api.customers.v1.test_helpers.customer.add_customer_service.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/service, respond with HTTP 401

## api.customers.v1.test_helpers.customer.disable_customer module

`api.customers.v1.test_helpers.customer.disable_customer.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+, respond with HTTP 403

`api.customers.v1.test_helpers.customer.disable_customer.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+, respond with HTTP 404

`api.customers.v1.test_helpers.customer.disable_customer.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+, respond with HTTP 200

`api.customers.v1.test_helpers.customer.disable_customer.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+, respond with HTTP 401

## api.customers.v1.test_helpers.customer.get_customer_by_id module

`api.customers.v1.test_helpers.customer.get_customer_by_id.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+, respond with HTTP 403

`api.customers.v1.test_helpers.customer.get_customer_by_id.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+, respond with HTTP 404

`api.customers.v1.test_helpers.customer.get_customer_by_id.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+, respond with HTTP 200

`api.customers.v1.test_helpers.customer.get_customer_by_id.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+, respond with HTTP 401

## api.customers.v1.test_helpers.customer.get_customer_by_shortname module

`api.customers.v1.test_helpers.customer.get_customer_by_shortname.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+, respond with HTTP 403

`api.customers.v1.test_helpers.customer.get_customer_by_shortname.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+, respond with HTTP 404

`api.customers.v1.test_helpers.customer.get_customer_by_shortname.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+, respond with HTTP 200

`api.customers.v1.test_helpers.customer.get_customer_by_shortname.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+, respond with HTTP 401

## api.customers.v1.test_helpers.customer.get_customer_logo_by_id module

`api.customers.v1.test_helpers.customer.get_customer_logo_by_id.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/logo, respond with HTTP 403

`api.customers.v1.test_helpers.customer.get_customer_logo_by_id.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/logo, respond with HTTP 404

`api.customers.v1.test_helpers.customer.get_customer_logo_by_id.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/logo, respond with HTTP 200

`api.customers.v1.test_helpers.customer.get_customer_logo_by_id.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/logo, respond with HTTP 401

## api.customers.v1.test_helpers.customer.get_customer_logo_by_shortname module

`api.customers.v1.test_helpers.customer.get_customer_logo_by_shortname.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/logo, respond with HTTP 403

`api.customers.v1.test_helpers.customer.get_customer_logo_by_shortname.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/logo, respond with HTTP 404

`api.customers.v1.test_helpers.customer.get_customer_logo_by_shortname.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/logo, respond with HTTP 200

`api.customers.v1.test_helpers.customer.get_customer_logo_by_shortname.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/logo, respond with HTTP 401

## api.customers.v1.test_helpers.customer.list_customers module

`api.customers.v1.test_helpers.customer.list_customers.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer, respond with HTTP 403

`api.customers.v1.test_helpers.customer.list_customers.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer, respond with HTTP 404

`api.customers.v1.test_helpers.customer.list_customers.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer, respond with HTTP 200

`api.customers.v1.test_helpers.customer.list_customers.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer, respond with HTTP 401

## api.customers.v1.test_helpers.customer.reenable_customer module

`api.customers.v1.test_helpers.customer.reenable_customer.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/reenable, respond with HTTP 403

`api.customers.v1.test_helpers.customer.reenable_customer.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/reenable, respond with HTTP 404

`api.customers.v1.test_helpers.customer.reenable_customer.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/reenable, respond with HTTP 200

`api.customers.v1.test_helpers.customer.reenable_customer.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/reenable, respond with HTTP 401

## api.customers.v1.test_helpers.customer.remove_customer_service module

`api.customers.v1.test_helpers.customer.remove_customer_service.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/service/w+, respond with HTTP 403

`api.customers.v1.test_helpers.customer.remove_customer_service.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/service/w+, respond with HTTP 404

`api.customers.v1.test_helpers.customer.remove_customer_service.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/service/w+, respond with HTTP 200

`api.customers.v1.test_helpers.customer.remove_customer_service.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+/service/w+, respond with HTTP 401

## api.customers.v1.test_helpers.customer.search_customers module

`api.customers.v1.test_helpers.customer.search_customers.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/search, respond with HTTP 403

`api.customers.v1.test_helpers.customer.search_customers.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/search, respond with HTTP 404

`api.customers.v1.test_helpers.customer.search_customers.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/search, respond with HTTP 200

`api.customers.v1.test_helpers.customer.search_customers.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/search, respond with HTTP 401

## api.customers.v1.test_helpers.customer.update_customer module

`api.customers.v1.test_helpers.customer.update_customer.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+, respond with HTTP 403

`api.customers.v1.test_helpers.customer.update_customer.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+, respond with HTTP 404

`api.customers.v1.test_helpers.customer.update_customer.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+, respond with HTTP 200

`api.customers.v1.test_helpers.customer.update_customer.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/customers/v1/customer/w+, respond with HTTP 401

## Module contents